// forms.go
package main

import (
	"fmt"

	"net/http"

	"github.com/gorilla/mux"
	"github.com/rs/cors"

	"tps-git.topcon.com/goutil/config-go"
	"tps-git.topcon.com/goutil/fatal-go"
	"tps-git.topcon.com/goutil/logger-go"
)

func main() {
	redirectPort := config.EnvInt("REDIRECT_PORT", 3434)
	oauthorizer := NewOAuthorize("http", "localhost", redirectPort)
	router := mux.NewRouter().StrictSlash(true)

	// pages to manage OAuth2:
	oauthorizer.AddHandlers(router)

	// enable cors:
	c := cors.New(cors.Options{
		AllowedOrigins:   []string{oauthorizer.ServerURL},
		AllowedMethods:   []string{"GET", "HEAD", "OPTIONS", "POST", "PUT", "DELETE"},
		AllowedHeaders:   []string{"Content-Type", "Content-Length", "Accept-Encoding", "Authorization", "Accept", "Origin", "If-None-Match", "If-Match"},
		ExposedHeaders:   []string{"Allow", "Content-Length", "Cursor", "ETag"},
		AllowCredentials: true,
	})

	logger.Noticef("Serving on HTTP port %d", redirectPort)
	fatal.OnError(http.ListenAndServe(fmt.Sprintf(":%d", redirectPort), c.Handler(router)))
}
